@@ -3,6 +3,7 @@ from dataclasses import dataclass, fields, MISSING
 from typing import Any, Dict, Optional, Union
 
 
+@dataclass
 class BaseConfig:
     @classmethod
     def from_dict(cls, data: Dict[str, Any]):
@@ -21,7 +22,7 @@ class BaseConfig:
             for f in fields(cls)
             if f.name in _data
         }
-        return cls(**members, **_data)  # type: ignore
+        return cls(**members, **_data)
 
     @classmethod
     def empty(cls, **kwargs):
@@ -32,13 +33,13 @@ class BaseConfig:
                 required_fields = (
                     (f.name, f.type)
                     for f in fields(T)
-                    if f.default is MISSING and f.default_factory is MISSING  # type: ignore
+                    if f.default is MISSING and f.default_factory is MISSING
                 )
                 converted = {
                     f_name: _empty(f_type) for f_name, f_type in required_fields
                 }
                 converted.update(kwargs)
-                return T(**converted)  # type: ignore
+                return T(**converted)
             return ""
 
         return _empty(cls, **kwargs)
@@ -48,7 +49,7 @@ def unwrap_optional_type(T: type) -> type:
     opt_types = getattr(T, "__args__", ())
     if not isinstance(None, opt_types) or getattr(T, "__origin__", None) is not Union:
         return T
-    return opt_types[0]
+    return opt_types[0]  # type: ignore
 
 
 @dataclass
