@@ -24,3 +24,13 @@ def patch_request(monkeypatch):
         return mock_request
 
     return response
+
+
+@pytest.fixture
+def patch_request_side_effect(monkeypatch):
+    def response(side_effect, method: str = "get") -> Mock:
+        mock_request = Mock(side_effect=side_effect)
+        monkeypatch.setattr(requests, method, mock_request)
+        return mock_request
+
+    return response
